/*
---------------------------------------------------------------------
ARCHITECTURE STRATEGIES
Code Source: "PROTECTING SQL SERVER DATA"
Author: John Magnabosco
Publisher: Simple Talk Publishing
Copyright September 2009
---------------------------------------------------------------------
Please note that it is highly discouraged to implement the provided sample code, 
either entirely or in part, on an instance of SQL Server that is actively utilized 
for production activity. All sample code is provided for illustrative purposes only 
and are provided as is without any warranties or guarantees of any kind, either expressed 
or implied. In no event shall the author or publisher be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages arising in any way out of the use 
of the provided sample code.
---------------------------------------------------------------------
*/

/* Listing 3-1: Qualifying object names in cross-database queries */
/****** CHANGE THE DATABASE1 REFERENCE ACCORDING TO YOUR ENVIRONMENT ******/
SELECT
   bnam.Last_Name,
   ident.Identification_Value
FROM
   Database1.dbo.Borrower bor
        INNER JOIN Database1.dbo.Borrower_Name bnam
      ON bor.Borrower_ID = bnam.Borrower_ID
   INNER JOIN Database2.dbo.Borrower_Identification bi
      ON bor.Borrower_ID = bi.Borrower_ID;
GO

/* Listing 3-2: Creating the Income_Schema database object schema */
Use HomeLending;
GO

CREATE SCHEMA [Income_Schema] AUTHORIZATION [db_owner];
GO

/* Listing 3-3: Granting permission to select, insert and update data in Income_Schema to the Sensitive_high database role */
Use HomeLending;
GO

GRANT SELECT, INSERT, UPDATE 
        ON SCHEMA::Income_Schema 
        TO Sensitive_high;
GO

/* Listing 3-4: Using fully qualified database object names */
Use HomeLending;
GO

SELECT
   be.Employer_Name,
   bi.Income_Amount,
   it.Income_Type_Desc
FROM
   dbo.Borrower_Employer be
   INNER JOIN Income_Schema.Borrower_Income bi
      ON be.Employer_ID = bi.Employer_ID
   INNER JOIN Income_Schema.Income_Type it
      ON bi.Income_Type_ID = it.Income_Type_ID;
GO

/* Listing 3-5: Creating a view in the HomeLending database */
Use HomeLending;
GO

CREATE VIEW [dbo].[vwBorrower]
AS
SELECT     
    b.Borrower_ID, 
    ba.Borrower_Address_Street,
    ba.Borrower_Address_City,
    ba.Borrower_Address_State,
    ba.Borrower_Address_Zipcode,
    at.Address_Type_Desc, 
    bn.Borrower_LName,  
    bn.Borrower_MName,
    bn.Borrower_FName
FROM         
    dbo.Borrower b
    INNER JOIN dbo.Borrower_Address ba
    ON b.Borrower_ID = ba.Borrower_ID 
    INNER JOIN dbo.Borrower_Name bn
    ON b.Borrower_ID = bn.Borrower_ID 
    INNER JOIN dbo.Address_Type at
    ON ba.Address_Type_ID = at.Address_Type_ID;
GO

/* Listing 3-6: Granting to the database role, Sensitive_medium, permission to select on the view vwBorrower */
Use HomeLending;
GO

GRANT SELECT 
   ON dbo.vwBorrower 
   TO Sensitive_medium;
GO

/* Listing 3-7: Denying SELECT privileges to the SQL Server login JOHNSONTE */
Use HomeLending;
GO

DENY SELECT 
        ON dbo.vwBorrower 
        TO JOHNSONTE;
GO

/* Listing 3-8: Returning SELECT privileges to JOHNSONTE */
Use HomeLending;
GO

REVOKE SELECT 
        ON dbo.vwBorrower 
        FROM JOHNSONTE;
GO

/* Listing 3-9: Implementing a linked server */
/****** CHANGE THE SERVER REFERENCE ACCORDING TO YOUR ENVIRONMENT ******/
USE Master;
GO

EXEC dbo.sp_addlinkedserver 
   @server = N'SERVER2\SQLINSTANCEB', 
   @srvproduct=N'SQL Server';
GO

EXEC dbo.sp_addlinkedsrvlogin 
   @rmtsrvname=N'SERVER2\SQLINSTANCEB',
   @useself=N'True',
   @locallogin=NULL,
   @rmtuser=NULL,
   @rmtpassword=NULL;
GO

/* Listing 3-10: Query the Linked Server */
/****** CHANGE THE SERVER REFERENCE ACCORDING TO YOUR ENVIRONMENT ******/
Use HomeLending;
GO

SELECT
   ln.Lender_Case_Number,
   cr.Credit_Score,
   cr.Beacon_Score,
   cr.Date_Report_Requested
FROM
   dbo.Loan ln
   INNER JOIN dbo.Loan_Credit_Report lncr
      ON ln.Loan_ID = lncr.Loan_ID
   INNER JOIN [SERVER2\SQLINSTANCEB].CreditReport
                   .dbo.Credit_Report cr
      ON lncr.Credit_Report_ID = cr.Credit_Report_ID;
GO







