/*
---------------------------------------------------------------------
CREATES DATABASE ROLES, USERS and ASSIGN MEMBERS TO ROLES
Code Source: "PROTECTING SQL SERVER DATA"
Author: John Magnabosco
Publisher: Simple Talk Publishing
Copyright September 2009
---------------------------------------------------------------------
Please note that it is highly discouraged to implement the provided sample code, 
either entirely or in part, on an instance of SQL Server that is actively utilized 
for production activity. All sample code is provided for illustrative purposes only 
and are provided as is without any warranties or guarantees of any kind, either expressed 
or implied. In no event shall the author or publisher be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages arising in any way out of the use 
of the provided sample code.
---------------------------------------------------------------------
*/

/* Listing 2-1: Creating the three sensitivity roles */
USE HomeLending;
GO

CREATE ROLE Sensitive_low AUTHORIZATION db_owner;
GO

CREATE ROLE Sensitive_medium AUTHORIZATION db_owner;
GO

CREATE ROLE Sensitive_high AUTHORIZATION db_owner;
GO


/* Listing 2-2: Creating six SQL Server logins */
-- Creates SQL Server Logins
CREATE LOGIN SMITHJW WITH PASSWORD = 'as98(*&sssr73x';
GO

CREATE LOGIN JONESBF WITH PASSWORD = 'ghls39**#kjlds';
GO

CREATE LOGIN JOHNSONTE WITH PASSWORD = 'asdpj3$dkEUmwm';
GO

CREATE LOGIN KELLEYWB WITH PASSWORD = 'lkjd&^aslkjdlJD';
GO

CREATE LOGIN REAGANCX WITH PASSWORD = 'HJ777jsb6$@jkjk';
GO

CREATE LOGIN WOLFBA WITH PASSWORD = 'hey4452h#552Vv';
GO


/* Listing 2-3: Creating the six database users, corresponding to our SQL Server logins */
USE HomeLending;
GO

-- Creates Database Users Mapped to SQL Server Logins
CREATE USER SMITHJW FOR LOGIN SMITHJW;
GO

CREATE USER JONESBF FOR LOGIN JONESBF;
GO

CREATE USER JOHNSONTE FOR LOGIN JOHNSONTE;
GO

CREATE USER KELLEYWB FOR LOGIN KELLEYWB;
GO

CREATE USER REAGANCX FOR LOGIN REAGANCX;
GO

CREATE USER WOLFBA FOR LOGIN WOLFBA;
GO

/* Listing 2-4: Implementing the inheritance hierarchy in our sensitivity classes */
USE HomeLending;
GO

-- Sensitive_medium role is a member of Sensitive_low
EXEC sp_addrolemember 'Sensitive_low', 'Sensitive_medium';
GO

-- Sensitive_high role is a member of Sensitive_medium
EXEC sp_addrolemember 'Sensitive_medium', 'Sensitive_high';
GO

/* Listing 2-5: Assigning members to the database roles */
USE HomeLending;
GO

-- These users have been determined to have access to low sensitive data
EXEC sp_addrolemember 'Sensitive_low', 'SMITHJW';
GO

EXEC sp_addrolemember 'Sensitive_low', 'JONESBF';
GO

-- These users have been determined to have access to meduim sensitive data
EXEC sp_addrolemember 'Sensitive_medium', 'JOHNSONTE';
GO

EXEC sp_addrolemember 'Sensitive_medium', 'KELLEYWB';
GO

-- These users have been determined to have access to highly sensitive data
EXEC sp_addrolemember 'Sensitive_high', 'REAGANCX';
GO

EXEC sp_addrolemember 'Sensitive_high', 'WOLFBA';
GO