/*
---------------------------------------------------------------------
HONEYCOMBING (SS2008 Only)
Code Source: "PROTECTING SQL SERVER DATA"
Author: John Magnabosco
Publisher: Simple Talk Publishing
Copyright September 2009
---------------------------------------------------------------------
Please note that it is highly discouraged to implement the provided sample code, 
either entirely or in part, on an instance of SQL Server that is actively utilized 
for production activity. All sample code is provided for illustrative purposes only 
and are provided as is without any warranties or guarantees of any kind, either expressed 
or implied. In no event shall the author or publisher be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages arising in any way out of the use 
of the provided sample code.
---------------------------------------------------------------------
*/

/* Listing 9.1: The Customer_Information Honeycomb table */
Use HomeLending;
GO

CREATE TABLE dbo.Customer_Information
(
	Customer_ID bigint IDENTITY(100,1) NOT NULL,
	First_Name varchar(50) NOT NULL,
	Last_Name varchar(50) NOT NULL,
	Social_Security_Number varchar(12) NOT NULL,
	Address_Street varchar(250) NOT NULL,
	Address_City varchar(150) NOT NULL,
	Address_State varchar(2) NOT NULL,
	Address_Zipcode varchar(10) NOT NULL
);
GO


/* Listing 9.2: Open season on the Honeycomb table */
Use HomeLending;
GO

GRANT SELECT, INSERT, UPDATE, DELETE
	ON dbo.Customer_Information
	TO public;
GO

/* Listing 9.3: Creating the Server Audit object */
USE Master;
GO

CREATE SERVER AUDIT Honeycomb_Audit
	TO APPLICATION_LOG;
GO

/* Listing 9.4: Activating the Honeycomb_Audit */
USE Master;
GO

ALTER SERVER AUDIT Honeycomb_Audit
WITH (STATE = ON);
GO

/* Listing 9.5: Creating the Database Audit Specification object */
Use HomeLending;
GO

CREATE DATABASE AUDIT SPECIFICATION Customer_Information_Spec
	FOR SERVER AUDIT Honeycomb_Audit
	ADD (SELECT, UPDATE, INSERT, DELETE
		 ON dbo.Customer_Information 
		 BY public)
	WITH (STATE = ON);
GO

/* Listing 9.6: Creating an operator to receive notifications */
USE msdb;
GO

EXEC msdb.dbo.sp_add_operator @name=N'DBA1', 
		@enabled=1, 
		@weekday_pager_start_time=0, 
		@weekday_pager_end_time=235959, 
		@saturday_pager_start_time=0, 
		@saturday_pager_end_time=235959, 
		@sunday_pager_start_time=0, 
		@sunday_pager_end_time=235959, 
		@pager_days=127, 
		@email_address=N'DBA1@homelending.com';
GO

/* Listing 9.7: Creating the Honeycomb Alert */
USE msdb;
GO

EXEC msdb.dbo.sp_add_alert @name=N'Honeycomb Alert', 
		@message_id=33205, 
		@severity=0, 
		@enabled=1, 
		@delay_between_responses=0, 
		@include_event_description_in=1, 
		@database_name=N'HomeLending', 
		@notification_message=N'Honeycomb Alert';
GO

/* Listing 9.8: Creating the notification */
USE msdb;
GO

EXEC msdb.dbo.sp_add_notification 
	@alert_name=N'Honeycomb Alert', 
	@operator_name=N'DBA1', 
	@notification_method = 1;
GO


