/*
---------------------------------------------------------------------
TRANSPARENT DATA ENCRYPTION (SS2008 Only)
Code Source: "PROTECTING SQL SERVER DATA"
Author: John Magnabosco
Publisher: Simple Talk Publishing
Copyright September 2009
---------------------------------------------------------------------
Please note that it is highly discouraged to implement the provided sample code, 
either entirely or in part, on an instance of SQL Server that is actively utilized 
for production activity. All sample code is provided for illustrative purposes only 
and are provided as is without any warranties or guarantees of any kind, either expressed 
or implied. In no event shall the author or publisher be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages arising in any way out of the use 
of the provided sample code.
---------------------------------------------------------------------
*/
/* Listing 6-1: Backing up the HomeLending database, prior to TDE */
USE HomeLending;
GO

BACKUP DATABASE HomeLending 
    TO DISK = 'D:\HomeLending\Backup\HomeLending.bak'
    WITH NOFORMAT, 
    INIT,  
    NAME = 'HomeLending-Full Database Backup', 
    SKIP, 
    NOREWIND, 
    NOUNLOAD,  
    STATS = 10
GO

/* Listing 6-2: Creating the database master key in the Master database */
USE master;
GO

CREATE MASTER KEY 
   ENCRYPTION BY PASSWORD = 'MyStr0ngP@ssw0rd2009';
GO

/* Listing 6-3: Confirming protection of the database master key by the service master key */
USE master;
GO

SELECT 
    b.name,
    a.crypt_type_desc 
FROM 
    sys.key_encryptions a
    INNER JOIN sys.symmetric_keys b
        ON a.key_id = b.symmetric_key_id
WHERE 
    b.name = '##MS_DatabaseMasterKey##';
GO

/* Listing 6-4: Creating the MasterCert self-signed certficate */
USE master;
GO

CREATE CERTIFICATE MasterCert 
    WITH SUBJECT = 'Cert used for TDE';
GO

/* Listing 6-5: Backing up the MasterCert certificate */
USE master;
GO

BACKUP CERTIFICATE MasterCert
    TO FILE = 'D:\HomeLending\Backup\MasterCert.bak'
    WITH PRIVATE KEY (
               FILE = 'D:\HomeLending\Backup\MasterCert.pvk',
               ENCRYPTION BY PASSWORD = 'MyB@ckUpP@ssw0rd');    
GO

/* Listing 6-6: Creating the HomeLending database encryption key */
USE HomeLending;
GO

CREATE DATABASE ENCRYPTION KEY
    WITH ALGORITHM = AES_128
    ENCRYPTION BY SERVER CERTIFICATE MasterCert;
GO

/* Listing 6-7: Enabling TDE */
USE HomeLending;
GO

ALTER DATABASE HomeLending
    SET ENCRYPTION ON;
GO

/* Listing 6-8: Verifying TDE using dm_database_encryption_keys */
USE master; 
GO

SELECT 
    db.name,
    db.is_encrypted,
    dm.encryption_state,
    dm.percent_complete,
    dm.key_algorithm,
    dm.key_length
FROM 
    sys.databases db
    LEFT OUTER JOIN sys.dm_database_encryption_keys dm
        ON db.database_id = dm.database_id;
GO

/* Listing 6-9: Backing up the HomeLending database after TDE is implemented */
USE HomeLending;
GO

BACKUP DATABASE HomeLending 
    TO DISK = 'D:\HomeLending\Backup\HomeLending_PostTDE.bak'
    WITH NOFORMAT, 
    INIT,  
    NAME = 'HomeLending-Full Database Backup', 
    SKIP, 
    NOREWIND, 
    NOUNLOAD,  
    STATS = 10
GO

